require File.dirname(__FILE__) + '/../abstract_unit'

begin
  require "RMagick"

  class ImageMagickNonCachingTestController < ActionController::Base
    imagemagick_for File.dirname(__FILE__) + "/../fixtures/imagemagick"
    
    def url_for(options, *parameters_for_method_reference)
      options
    end
  end
  
  class ImageMagickCachingPrerenderingTestController < ActionController::Base
    imagemagick_for File.dirname(__FILE__) + "/../fixtures/imagemagick",
                    :cache=>"/tmp/imagemagick_cache",
                    :prerender=>true
    
    def url_for(options, *parameters_for_method_reference)
      options
    end
  end
  
  class ImageMagickForTagTestController < ActionController::Base
    imagemagick_for File.dirname(__FILE__) + "/../fixtures/imagemagick"
    
    def url_for(options, *parameters_for_method_reference)
      options.to_s
    end
  end
  class ImageMagickForTagTestRequest
    def relative_url_root
      ""
    end
  end
  
  class ImageMagickCustomActionTestController < ActionController::Base
    imagemagick_for File.expand_path(File.dirname(__FILE__) + "/../fixtures/imagemagick"),
                    :action_name=>"customaction"
    
    def url_for(options, *parameters_for_method_reference)
      options
    end
  end
  
  class ImageMagickMacroHelperTest < Test::Unit::TestCase
    include ActionView::Helpers::ImageMagickMacroHelper
    
    include ActionView::Helpers::UrlHelper
    include ActionView::Helpers::TagHelper
    include ActionView::Helpers::AssetTagHelper
    
    def setup
      @controller = ImageMagickNonCachingTestController.new
      @controller_cache = ImageMagickCachingPrerenderingTestController.new
      
      FileUtils.mkdir("/tmp/imagemagick_cache")
    end
    
    def teardown
      FileUtils.rm_rf("/tmp/imagemagick_cache")
    end
    
    def test_imagemagick_path_without_commands
      expected_path = { :action=>"imagemagick",
                        :id=>"presentation.jpg" }
      assert_equal expected_path, imagemagick_path("presentation.jpg")
    end
  
    def test_imagemagick_path_with_commands
      expected_path = { :action=>"imagemagick",
                        :id=>"presentation.jpg",
                        :commands=>"resize(10)" }
      assert_equal expected_path, imagemagick_path("presentation.jpg", [[:resize,10]])
    end
  
    def test_imagemagick_path_with_prerendering
      @controller = @controller_cache
      expected_path = { :action=>"imagemagick",
                        :id=>"resize10.equalize.presentation.jpg" }
      assert_equal expected_path, imagemagick_path("presentation.jpg", [[:resize,10],[:equalize]])
      
      assert File.exists?("/tmp/imagemagick_cache/resize10.equalize.presentation.jpg")
    end
  
    def test_imagemagick_path_other_controller
      expected_path = { :action=>"imagemagick",
                        :id=>"resize10.equalize.presentation.jpg" }
      
      # should use the ImageMagickCachingPrerenderingTestController
      assert_equal expected_path, imagemagick_path("presentation.jpg", [[:resize,10],[:equalize]],
                                               {:controller=>'image_magick_caching_prerendering_test'})
      
      assert File.exists?("/tmp/imagemagick_cache/resize10.equalize.presentation.jpg")
    end
    
    def test_imagemagick_tag
      @controller = ImageMagickForTagTestController.new
      @request = ImageMagickForTagTestRequest.new
      
      assert imagemagick_tag("presentation.jpg") =~ /presentation.jpg/
      assert imagemagick_tag("presentation.jpg", "resize(100x100)") =~ /resize/
      assert imagemagick_tag("presentation.jpg", "x", :height=>100) =~ /height="100"/
    end
    
    def test_custom_action_imagemagick_tag
      @controller = ImageMagickCustomActionTestController.new
      
      expected_path = { :action=>"customaction",
                        :id=>"presentation.jpg" }
      assert_equal expected_path, imagemagick_path("presentation.jpg")
    end
  end

rescue LoadError
  # RMagick is not installed
end
